Method: JSON::Pure::Generator::GeneratorMethods::String#to_json_raw_object
- Defined in:
- lib/json/pure/generator.rb
#to_json_raw_object ⇒ Object
This method creates a raw object hash, that can be nested into other data structures and will be unparsed as a raw string. This method should be used, if you want to convert raw strings to JSON instead of UTF-8 strings, e. g. binary data.
412 413 414 415 416 417 |
# File 'lib/json/pure/generator.rb', line 412 def to_json_raw_object { JSON.create_id => self.class.name, 'raw' => self.unpack('C*'), } end |